<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Generic;

// Import framework stuff
use Org\Mxchange\CoreFramework\Generic\FrameworkException;
use Org\Mxchange\CoreFramework\Generic\FrameworkInterface;

/**
 * An exception thrown when an unfinished method is called or when it should
 * never be called.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2021 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class UnsupportedOperationException extends FrameworkException {
	/**
	 * The constructor
	 *
	 * @param	$classArray		Array holding the exception data
	 * @param	$code			Code number for the exception
	 * @return	void
	 */
	public function __construct (array $classArray, int $code) {
		// Init extra class name
		$extraClassName = '';

		// Do we have an extra instance?
		if ((isset($classArray[2])) && ($classArray[2] instanceof FrameworkInterface)) {
			// Get the class name
			$extraClassName = $classArray[2]->__toString();
		} // END - if

		// Add a message around the missing class
		$message = sprintf('[%s:%d] Method <u>%s()</u> is unsupported or should not be called. extraInstance=%s',
			$classArray[0]->__toString(),
			$this->getLine(),
			$classArray[1],
			$extraClassName
		);

		// Call parent constructor
		parent::__construct($message, $code);
	}

}
